#ifndef STDLIST_H
#include "stdlist.h"
#endif

#ifndef IOLIB_H
#include "iolib.h"
#endif

#define NOMACROS 1

#ifndef STDIO_H
#include "stdio.h"
#endif

#ifndef TIME_H
#include "time.h"
#endif


#ifdef ANSIC

#ifndef STDARG_H
#include "stdarg.h"
#endif


/* for compilers that support function prototypes */

/* Twelve support functions */
long SetSTDIO(void);
long SetupSTDIO(task_UserData *, long *, long *, long *, void *);
task_UserData *GetSTDIO(void);
void ClearSTDIO(void);
void closeall(void);
void SetAbortFunc(long (*)(long));
void ClearAbortFunc(void);
void cli_parse(task_UserData *, long, char *);
long wb_parse(task_Userdata *, long, char *);
char *scdir(char *);
void _exit(long);
void exit(long);

/* Forty Nine standard IO functions */
long open(char *,long,long);
long close(long);
long unlink(char *);
long stat(char *,struct stat *);
long rename(char *,char *);
long read(long, char *, long);
long write(long, char *, long);
long creat(char *, long);
long lseek(long, long, unsigned long);
long isatty(long);
long access(char *, long);
FILE *fopen(char *,char *);
FILE *freopen(char *, char *, FILE *);
long fclose(FILE *);
FILE *fdopen(long,char *);
void getbuff(FILE *);
long setvbuf(FILE *, char *, long, size_t);
char *mktemp(char *);
char *tmpnam(char *);
FILE *tmpfile(void);
short putc(short ,FILE *);
short aputc(short, FILE *);
short getc(FILE *);
short agetc(FILE *);
short ungetc(short,FILE *);
unsigned short putw(unsigned short,FILE *);
short puts(char *);
short puterr(short);
size_t fwrite(void *,size_t,size_t,FILE *);
long perror(char *);
long fseek(FILE *,long,long);
long ftell(FILE *);
short getw(FILE *);
long fflush(FILE *);
size_t fread(void *,size_t,size_t,FILE *);
char *gets(char *);
char *fgets(char *, long, FILE *);
long fputs(char *, FILE *);
long scanf(char *, ...);
long printf(char *, ...);
long fscanf(FILE *, char *, ...);
long fprintf(FILE *, char *, ...);
long sscanf(char *, char *, ...);
long sprintf(char *, char *, ...);
long vprintf(char *,va_list);
long vfprintf(FILE *,char *,va_list);
long vsprintf(char *,char *,va_list);
long fgetpos(FILE *,fpos_t *);
long fsetpos(FILE *,fpos_t *);


/* Thirteen memory allocation functions */
void *_alloc(task_UserData *,long,long);
void _fre(task_UserData *,void *);
void _freall(task_UserData *);
void *sbrk(long);
void *heap_alloc(unsigned long);
void heap_free(void *);
void *malloc(unsigned long);
void *calloc(unsigned long, unsigned long);
void *realloc(void *,unsigned long);
void free(void *);
void be_free(void *,unsigned long);
unsigned long malloc_size(void *);
void freeall(void);

/* Ten linked list functions */
_node *inst_node(long);
void put_head(_list *,_node *);
void *add_head(_list *,long);
void put_tail(_list *,_node *);
void *add_tail(_list *,long);
void *remv_head(_list *, void **);
void *remv_tail(_list *, void **);
void remv_list(_list *);
void *r_node(_list *,_node *,void **);
void *remv_node(_list *,void *);

/* Five format conversion functions */
short atoi(char *);
long atol(char *);
double atof(char *);
void ltoa(long, char *);
void stoa(short, char *);

/* Nine memory operation functions */
short bcmp(void *, void *, long);
void bcopy(void *, void *, long);
void bzero(void *, long);
void *memccpy(void *, void *, unsigned short, long);
void *memchr(void *, unsigned short, long);
short memcmp(void *, void *, long);
void *memcpy(void *, void *, long);
void *memset(void *, unsigned short, long);
void memswap(void *, void *, long);

/* Twenty Three string functions */
char *index(char *, short);
char *rindex(char *,short);
char *strupr(char *);
char *stpcrlf(char *);
char *strcat(char *, char *);
char *strchr(char *, short);
short strcmp(char *, char *);
char *strcpy(char *, char *);
long strcspn(char *, char *);
long strlen(char *);
char *strncat(char *, char *, long);
short strcmpa(char *, char *);
short strncmp(char *, char *, long);
char *strncpy(char *, char *, long);
char *strpbrk(char *, char *);
char *strrchr(char *, short);
long strspn(char *, char *);
char *strstr(char *, char *);
char *strtok(char *, char *);
char *strrv(char *);
char *strnrv(char *, long);
char *bcpl_strcpy(char *, BSTR *);
char *strerror(long);

/* Three sorting functions */
void vquicksort(unsigned short,short (*)(unsigned short,unsigned short),
     void (*)(unsigned short, unsigned short));
void quicksort(unsigned long, short (*)(unsigned long,unsigned long,void *),
     void (*)(unsigned long,unsigned long,void *),void *);
void qsort(void *,unsigned long,unsigned long,short (*)(void *,void *));

/* Nine time functions */
clock_t clock(void);
time_t time(time_t *);
long difftime(time_t,time_t);
time_t mktime(struct tm *);
char *asctime(struct tm *);
char *ctime(time_t *);
struct tm *gmtime(time_t *);
struct tm *localtime(time_t *);
size_t strftime(char *,size_t,char *,struct tm *);

#else

/* for compilers that do not support function prototypes */

long SetSTDIO();
long SetupSTDIO();
task_UserData *GetSTDIO();
void ClearSTDIO();
void closeall();
void SetAbortFunc();
void ClearAbortFunc();
void cli_parse();
long wb_parse();
char *scdir();
void _exit();
void exit();
long open();
long close();
long unlink();
long stat();
long rename();
long read();
long write();
long creat();
long lseek();
long isatty();
long access();
FILE *fopen();
FILE *freopen();
long fclose();
FILE *fdopen();
void getbuff();
long setvbuf();
char *mktemp();
char *tmpnam();
FILE *tmpfile();
short putc();
short aputc();
short getc();
short agetc();
short ungetc();
unsigned short putw();
short puts();
short puterr();
size_t fwrite();
long perror();
long fseek();
long ftell();
long fflush();
short getw();
size_t fread();
char *gets();
char *fgets();
long fputs();
long scanf();
long printf();
long fscanf();
long fprintf();
long sscanf();
long sprintf();
long vprintf();
long vfprintf();
long vsprintf();
long fgetpos();
long fsetpos();
void *_alloc();
void _fre();
void _freall();
void *sbrk();
void *heap_alloc();
void heap_free();
void *malloc();
void *calloc();
void *realloc();
void free();
void be_free();
unsigned long malloc_size();
void freeall();
_node *inst_node();
void put_head();
void *add_head();
void put_tail();
void *add_tail();
void *remv_head();
void *remv_tail();
void remv_list();
void *r_node();
void *remv_node();
short atoi();
long atol();
double atof();
void ltoa();
void stoa();
short bcmp();
void bcopy();
void bzero();
void *memccpy();
void *memchr();
short memcmp();
void *memcpy();
void *memset();
void memswap();
char *index();
char *rindex();
char *strupr();
char *stpcrlf();
char *strcat();
char *strchr();
short strcmp();
char *strcpy();
long strcspn();
long strlen();
char *strncat();
short strcmpa();
short strncmp();
char *strncpy();
char *strpbrk();
char *strrchr();
long strspn();
char *strstr();
char *strtok();
char *strrv();
char *strnrv();
char *bcpl_strcpy();
char *strerror();
void vquicksort();
void quicksort();
void qsort();
clock_t clock();
time_t time();
long difftime();
time_t mktime();
char *asctime();
char *ctime();
struct tm *gmtime();
struct tm *localtime();
size_t strftime();



#endif
